/*
 * Segment 2 (KEx),  SWE 2.WebFS Web Feature Service
 * Copyright (C) 2007 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weienfelser Strae 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.wfs.wfs;

/**
 * Legt die Typen, Attributgruppen und Aspekte fest, die &uuml;ber den WFS
 * bereitgestellt werden sollen. Es werden "ObjektTyp", "Attributgruppe" und
 * "Aspekt" der bereitzustellenden Daten konfiguriert. Mehrere Eintr&auml;ge
 * f&uuml;r einen ObjektTyp sind mglich, das Feature wird dann aus allen
 * Attributgruppen dieses Typs gebildet. Die die Geometrie eines Typs
 * beschreibende Attributgruppe mu&szlig; nicht notwendigerweise parametriert
 * werden. Die SWE versucht fr alle konfigurierten Typen eine Geometrie nach
 * folgendem Algorithmus zu bestimmen:
 * 
 * <p>
 * Wenn der Typ von einem der Typen des TeilmodellGeoReferenzierungGlobal
 * abgeleitet ist, wird die Geometrie aus dem entsprechenden Basistyp gebildet.
 * Konnte damit keine Geometrie gefunden werden, werden die f&uuml;r den Typ die
 * konfigurierten Attributgruppen nach folgenden Attributgruppen als Basis
 * f&uuml;r die Geometrie durchsucht:
 * 
 * atg.punktKoordinaten atg.linienKoordinaten atg.flchenKoordinaten
 * atg.komplexKoordinaten atg.bestehtAusLinienObjekten
 * 
 * Falls im Typ eine der obigen Attributgruppen existiert, wird diese verwendet.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 * 
 */
public final class ExportObjekteDefault {
	/**
	 * Enth&auml;lt je Eintrag jeweils die Pid des ObjektTyps, die Pid der
	 * Attributgruppe sowie den Aspekt.
	 */
	@SuppressWarnings("nls")
	private static final Object[][] EXPORTOBJEKTE = new Object[][] {
			// ObjektTyp, Attributgruppe, Aspekt
			{ "typ.tmcPunkt", "atg.punktKoordinaten", "asp.eigenschaften" },
			{ "typ.tmcPunkt", "atg.tmcLocationCode", "asp.eigenschaften" },
			{ "typ.tmcLinie", "atg.linienKoordinaten", "asp.eigenschaften" },
			{ "typ.tmcLinie", "atg.tmcLocationCode", "asp.eigenschaften" },
			{ "typ.tmcGebiet", "atg.flchenKoordinaten", "asp.eigenschaften" },
			{ "typ.tmcGebiet", "atg.tmcLocationCode", "asp.eigenschaften" },
			{ "typ.messQuerschnitt", "atg.punktKoordinaten",
					"asp.eigenschaften" },
			{ "typ.straenTeilSegment", "atg.linienKoordinaten",
					"asp.eigenschaften" },
			{ "typ.straenTeilSegment", "atg.straenTeilSegment",
					"asp.eigenschaften" },
			{ "typ.ueresStraenSegment", "atg.bestehtAusLinienObjekten",
					"asp.eigenschaften" },
			{ "typ.ueresStraenSegment", "atg.ueresStraenSegment",
					"asp.eigenschaften" },
			{ "typ.ueresStraenSegment", "atg.straenSegment",
					"asp.eigenschaften" },
			{ "typ.inneresStraenSegment", "atg.bestehtAusLinienObjekten",
					"asp.eigenschaften" },
			{ "typ.inneresStraenSegment", "atg.inneresStraenSegment",
					"asp.eigenschaften" },
			{ "typ.inneresStraenSegment", "atg.straenSegment",
					"asp.eigenschaften" },
			{ "typ.anzeigeQuerschnitt", "atg.punktKoordinaten",
					"asp.eigenschaften" }, };

	/**
	 * Gibt die Liste der Objekte zur&uml;ck.
	 * 
	 * @return die Liste der zu exportierenden Objekte
	 */
	public static Object[][] getExportObjekte() {
		return EXPORTOBJEKTE;
	}

	/**
	 * Privater Konstruktor.
	 */
	private ExportObjekteDefault() {
		/** nur zur Beruhigung von CheckStyle */
	}
}
