/*
 * Segment 2 (KEx),  SWE 2.WebFS Web Feature Service
 * Copyright (C) 2007 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weienfelser Strae 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.wfs.wfs;

import java.io.File;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;

/**
 * Klasse mit Werkzeugen zur Arbeit mit XML-dateien.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: XMLTools.java 8188 2008-04-14 16:06:59Z gieseler $
 * 
 */

public final class XMLTools {

	/**
	 * Gibt ein {@link Document} als XML-Datei aus.
	 * 
	 * @param doc
	 *            {@link Document}
	 * @param datei
	 *            Name der Datei
	 * @throws WFSException
	 *             bei Ausnahmen
	 */
	public static void schreibeXMLDatei(final Document doc, final File datei)
			throws WFSException {
		try {
			Source source = new DOMSource(doc);

			Result result = new StreamResult(datei);

			Transformer xformer = TransformerFactory.newInstance()
					.newTransformer();
			xformer.setOutputProperty(OutputKeys.INDENT, "yes");
			xformer.setOutputProperty(OutputKeys.OMIT_XML_DECLARATION, "no");
			xformer.setOutputProperty(OutputKeys.OMIT_XML_DECLARATION, "no");
			xformer.transform(source, result);
		} catch (TransformerConfigurationException e) {
			throw new WFSException(e.getMessage());
		} catch (TransformerException e) {
			throw new WFSException(e.getMessage());
		}
	}

	/**
	 * Privater Konstruktor.
	 */
	private XMLTools() {
		/** nur zur Beruhigung von CheckStyle */
	}
}
